@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
-from flask import Blueprint, current_app, json
-from xmlrpclib import ServerProxy
+from flask import Blueprint, current_app, json, session
+from xmlrpc.client import ServerProxy
 from flask.views import MethodView
 from eoleauthlib.authclient import login_required
 
@@ -11,15 +11,20 @@ class GroupsAPI(MethodView):
 
     def __init__(self):
         self.proxy = ServerProxy(current_app.config['CONTROLEVNC_URL'])
+        self.username = session["username"]
 
     def get(self, typegroup):
         """Returns the list of groups with the given type
            Possible group types : "classe", "niveau", "matiere", "equipe", "groupe"
         """
+        if self.username is None:
+            current_app.logger.warning('Unbound use of the API, no session username defined!')
+            return json.dumps('Error: You need a username to talk to backend')
+
         if typegroup is None:
             current_app.logger.warning('Unbound use of the API: required typegroup is not provided.')
             return json.dumps('Error: You need a typegroup to talk to backend')
-        return json.dumps(self.proxy.remote_groupes(typegroup))
+        return json.dumps(self.proxy.remote_groupes(typegroup, self.username))
 
     def post(self):
         raise NotImplementedError
